==> 1.0.1.tar.gz: lib/src/core/widgets/inputs/ModernFormTextsInput.dart <==
part of modern_form_core;

class ModernFormTextsInput extends StatelessWidget {
  final String? bottomSheetLabelText;
  final String? buttonText;
  final void Function(List<String> selecteds)? onChanged;
  final List<String?>? initialValue;
  final Future<void> Function()? onTap;
  final String? cancel;
  final TextStyle? cancelStyle;
  final String? done;
  final List<SecondOption>? options;
  final TextCapitalization? textCapitalization;

  const ModernFormTextsInput({
    Key? key,
    this.bottomSheetLabelText,
    this.buttonText,
    this.onChanged,
    this.initialValue,
    this.onTap,
    this.cancel,
    this.cancelStyle,
    this.done,
    this.options,
    this.textCapitalization,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    bool isOptionals = options != null && options!.isNotEmpty;

    return Padding(
      padding: EdgeInsets.only(top: ScreenUtil().setSp(8)),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          ListView.builder(
              shrinkWrap: true,
              physics: NeverScrollableScrollPhysics(),
              itemCount: initialValue?.length ?? 0,
              itemBuilder: (context, index) {
                String? iten = initialValue![index];
                return Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    SelectableText(iten ?? "",
                        style: TextStyle(fontSize: ScreenUtil().setSp(14))),
                    Builder(
                      builder: (context) {
                        return IconButton(
                          icon: Icon(isOptionals ? Icons.edit : Icons.close,
                              size: ScreenUtil().setSp(19)),
                          onPressed: () async {
                            if (isOptionals) {
                              SecondOption? option =
                                  await showSecondOption(context, options);
                              if (option != null) {
                                switch (option) {
                                  case SecondOption.Edit:
                                    onEdit(context, index);
                                    break;
                                  case SecondOption.Delete:
                                    onDelete(index);
                                    break;
                                  case SecondOption.Move:
                                    onMove(context, index);
                                    break;
                                  default:
                                    break;
                                }
                              }
                            } else {
                              onDelete(index);
                            }
                          },
                        );
                      },
                    ),
                  ],
                );
              }),
          SizedBox(height: ScreenUtil().setHeight(7)),
          ElevatedButton.icon(
            label: Icon(Icons.add, size: ScreenUtil().setSp(18)),
            icon: Text(
              buttonText ?? "Adicionar",
              style: TextStyle(fontSize: ScreenUtil().setSp(14)),
            ),
            onPressed: () async {
              if (onTap != null) {
                await onTap!();
              }
              TextEditingController? c = await showModernFormInputText(
                context,
                label: bottomSheetLabelText,
                done: done,
                cancel: cancel,
                textCapitalization: textCapitalization,
              );
              if (c != null) {
                if (initialValue == null) {
                  if (onChanged != null) {
                    onChanged!([c.text]);
                  }
                } else {
                  List<String> _v = List<String>.from(initialValue ?? []);

                  _v.add(c.text);
                  if (onChanged != null) {
                    onChanged!(_v);
                  }
                }
              }

              // if (_itens != null) {
              //   selecteds = _itens;
              //   widget.onChanged(selecteds);
              // }
            },
          ),
        ],
      ),
    );
  }

  Future<void> onEdit(BuildContext context, int index) async {
    TextEditingController? c = await showModernFormInputText(
      context,
      label: bottomSheetLabelText,
      done: done,
      cancel: cancel,
      controller: TextEditingController(text: initialValue![index]),
    );
    if (c != null && onChanged != null) {
      List<String> _v = List<String>.from(initialValue ?? []);
      _v[index] = c.text;
      onChanged!(_v);
    }
  }

  Future<void> onMove(BuildContext context, int index) async {
    int? newIndex =
        await showMoveTo(context, (initialValue?.length ?? 0), index);

    if (newIndex != null && onChanged != null) {
      List<String> _v = List<String>.from(initialValue ?? []);
      String iten = _v[index];
      _v.removeAt(index);
      _v.insert(newIndex, iten);
      onChanged!(_v);
    }
  }

  void onDelete(int index) {
    dialogDelete(() {
      List<String> _v = List<String>.from(initialValue ?? []);
      _v.removeAt(index);
      if (onChanged != null) {
        onChanged!(_v);
      }
    });
  }
}

==> 1.0.13.tar.gz: lib/src/core/widgets/inputs/ModernFormTextsInput.dart <==
part of modern_form_core;

class ModernFormTextsInput extends StatelessWidget {
  final String? bottomSheetLabelText;
  final String? buttonText;
  final void Function(List<String> selecteds)? onChanged;
  final List<String?>? initialValue;
  final Future<void> Function()? onTap;
  final String? cancel;
  final TextStyle? cancelStyle;
  final String? done;
  final List<SecondOption>? options;
  final TextCapitalization? textCapitalization;

  const ModernFormTextsInput({
    Key? key,
    this.bottomSheetLabelText,
    this.buttonText,
    this.onChanged,
    this.initialValue,
    this.onTap,
    this.cancel,
    this.cancelStyle,
    this.done,
    this.options,
    this.textCapitalization,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    bool isOptionals = options != null && options!.isNotEmpty;

    return Padding(
      padding: EdgeInsets.only(top: ScreenUtil().setSp(8)),
      child: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          ListView.builder(
              shrinkWrap: true,
              physics: NeverScrollableScrollPhysics(),
              itemCount: initialValue?.length ?? 0,
              itemBuilder: (context, index) {
                String? iten = initialValue![index];
                return Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    SelectableText(iten ?? "",
                        style: TextStyle(fontSize: ScreenUtil().setSp(14))),
                    Builder(
                      builder: (context) {
                        return IconButton(
                          icon: Icon(isOptionals ? Icons.edit : Icons.close,
                              size: ScreenUtil().setSp(19)),
                          onPressed: () async {
                            if (isOptionals) {
                              SecondOption? option =
                                  await showSecondOption(context, options!);
                              if (option != null) {
                                switch (option) {
                                  case SecondOption.Edit:
                                    onEdit(context, index);
                                    break;
                                  case SecondOption.Delete:
                                    onDelete(index);
                                    break;
                                  case SecondOption.Move:
                                    onMove(context, index);
                                    break;
                                  default:
                                    break;
                                }
                              }
                            } else {
                              onDelete(index);
                            }
                          },
                        );
                      },
                    ),
                  ],
                );
              }),
          SizedBox(height: ScreenUtil().setHeight(7)),
          ElevatedButton.icon(
            label: Icon(Icons.add, size: ScreenUtil().setSp(18)),
            icon: Text(
              buttonText ?? "Adicionar",
              style: TextStyle(fontSize: ScreenUtil().setSp(14)),
            ),
            onPressed: () async {
              if (onTap != null) {
                await onTap!();
              }
              TextEditingController? c = await showModernFormInputText(
                context,
                label: bottomSheetLabelText,
                done: done,
                cancel: cancel,
                textCapitalization: textCapitalization,
              );
              if (c != null) {
                if (initialValue == null) {
                  if (onChanged != null) {
                    onChanged!([c.text]);
                  }
                } else {
                  List<String> _v = List<String>.from(initialValue ?? []);

                  _v.add(c.text);
                  if (onChanged != null) {
                    onChanged!(_v);
                  }
                }
              }

              // if (_itens != null) {
              //   selecteds = _itens;
              //   widget.onChanged(selecteds);
              // }
            },
          ),
        ],
      ),
    );
  }

  Future<void> onEdit(BuildContext context, int index) async {
    TextEditingController? c = await showModernFormInputText(
      context,
      label: bottomSheetLabelText,
      done: done,
      cancel: cancel,
      controller: TextEditingController(text: initialValue![index]),
    );
    if (c != null && onChanged != null) {
      List<String> _v = List<String>.from(initialValue ?? []);
      _v[index] = c.text;
      onChanged!(_v);
    }
  }

  Future<void> onMove(BuildContext context, int index) async {
    int? newIndex =
        await showMoveTo(context, (initialValue?.length ?? 0), index);

    if (newIndex != null && onChanged != null) {
      List<String> _v = List<String>.from(initialValue ?? []);
      String iten = _v[index];
      _v.removeAt(index);
      _v.insert(newIndex, iten);
      onChanged!(_v);
    }
  }

  void onDelete(int index) {
    dialogDelete(() {
      List<String> _v = List<String>.from(initialValue ?? []);
      _v.removeAt(index);
      if (onChanged != null) {
        onChanged!(_v);
      }
    });
  }
}
